@@ -152,6 +152,28 @@ class ControlPanel(tk.Frame):
         raise NotImplementedError
 
 
+    def set_state(self, name:str, state:Any):
+
+        try:
+            widget = self.widgets[name]
+        except KeyError:
+            raise KeyError(f"The widget with name '{name}' does not exist.")
+
+        if isinstance(widget, ttk.Checkbutton):
+            if self.get_state(name) != state:
+                widget.invoke()
+
+        elif isinstance(widget, tk.OptionMenu):
+            self.widgets[f'{name}_variable'].set(state)
+
+        elif isinstance(widget, tk.Scale):
+            widget.set(state)
+
+        else:
+            raise NotImplementedError
+
+
+
     def attach(self, other:'ControlPanel'):
         other.parent = self
         other.hide()
